function [Y, none, rep, atr] = carteShift(carte1, carte2, ori, tracer)
% Trace (si tracer = true, c est le cas par defaut) la carte des shifts attractifs et repulsigf entre les carte 1 et 2
% par rapport a l orientation adaptante ori. Retourne :
% Y : carte des shifts par rapport à l orientation ori
% none : le nombre de pixles sans shiftsle (shift < 5 degres)
% rep : nombre de pixels dont le shift est repulsif
% atr : nombre de pixels dont le shift est attractif

if nargin < 4
  tracer = true; 
end

Y = shift(carte1, carte2, ori);
[none, rep, atr] = getNatNrepNone(Y);
if tracer
    figure
    imagesc(Y);    
    colorbar;
end

